aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--build-aux/qmi-codegen/Client.py4
1 files changed, 3 insertions, 1 deletions
diff --git a/build-aux/qmi-codegen/Client.py b/build-aux/qmi-codegen/Client.py
index 071c91b..1e342ae 100644
--- a/build-aux/qmi-codegen/Client.py
+++ b/build-aux/qmi-codegen/Client.py
@@ -43,9 +43,11 @@ class Client:
elif object_dictionary['type'] == 'Service':
self.service = object_dictionary['name']
# We NEED the Client field
if self.name is None:
raise ValueError('Missing Client field')
+ if self.service is None:
+ raise ValueError('Missing Service field')
"""
@@ -43,9 +43,11 @@ class Client:
elif object_dictionary['type'] == 'Service':
self.service = object_dictionary['name']
- # We NEED the Client field
+ # We NEED the Client field and the Service field
if self.name is None:
raise ValueError('Missing Client field')